Document

Struct Document 

pub struct Document {
    pub id: String,
    pub text: String,
    pub embedding: Option<Vec<f32>>,
    pub embedding_name: Option<String>,
    pub metadata: Option<Value>,
}
Document structure for serializing and deserializing when working with vector databases.

The id field is a unique identifier for the document. If not provided, it will be generated using a hash of the text field. The text field is the main content of the document. The embedding field is an optional field that can be used to store a vector embedding of the document. The embedding_name field is the name of the field that the embedding is stored in. The metadata field is an optional field that can be used to store additional metadata about the document.

Fields

id: Stringtext: Stringembedding: Option<Vec<f32>>embedding_name: Option<String>metadata: Option<Value>

Implementations

Source

impl Document

pub fn new(text: String) -> Self

Create a new document with the given text.

pub fn new_with_id(id: String, text: String) -> Self

Create a new document with the given id and text.

pub fn new_with_embedding( text: String, embedding: Vec<f32>, embedding_name: String, ) -> Self

Create a new document with the given text and embedding.