pub struct OpenAIChatModel<T> { /* private fields */ }Expand description
Represents a processor for sending and processing requests to the OpenAI API.
OpenAIChatModel encapsulates the functionality required to interact with
the OpenAI Chat API, handling both the construction of requests and the
parsing of responses.
Implementations
Sourceimpl<T> OpenAIChatModel<T>
impl<T> OpenAIChatModel<T>
Sourcepub async fn new_with_key(
system_prompt: String,
model: String,
api_key: String,
) -> Self
pub async fn new_with_key( system_prompt: String, model: String, api_key: String, ) -> Self
Constructs a new OpenAI node using the specified API key.
The system prompt is passed in as the first message in the conversation
using ChatCompletionRequestSystemMessage.